@@ -1,36 +1,22 @@
 from subprocess import call
 from landslide.generator import Generator
 import os
-import sys
 import time
-from optparse import OptionParser
 
 description = """
 %prog [slides - print the slides | links - print the links]
 """
 
-def parse_options():
-    parser = OptionParser(
-        usage="%prog [options] slides|links",
-        description=description
-    )
-
-    (options, args) = parser.parse_args()
-
-    if not args:
-        parser.print_help()
-        sys.exit(1)
-
-    return options, args
 
 def dirname():
     return os.path.dirname(os.path.realpath(__file__))
 
+
 def file_in_dir(filename):
     return os.path.join(dirname(), 'data', filename)
 
+
 def open_slides():
-    cmd = "landslide -o out.html {0}".format(file_in_dir('slides.md'))
     slides_path = file_in_dir('slides.md')
     output_path = 'pipped-slides.html'
     Generator(slides_path, **{
@@ -46,9 +32,8 @@ def open_slides():
 
     call(['rm', output_path])
 
+
 def run():
-    options, args = parse_options()
-    if args[-1] == 'slides':
-        open_slides()
-    else:
-        print('do it')
+    print("publising pip packages - nyc python talk on 2014-06-12")
+    print("code available at https://github.com/brianc/publishing-pip-packages")
+    open_slides()
